<?php

namespace Sample\Users\Providers;

use Illuminate\Support\ServiceProvider;

class UsersServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'users');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'users');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('users', function ($app) {
            return $this->app->make('Sample\Users\Users');
        });

        // Bind User to repository
        $this->app->bind(
            \Sample\Users\Interfaces\UserRepositoryInterface::class,
            \Sample\Users\Repositories\Eloquent\UserRepository::class
        );

        $this->app->register(\Sample\Users\Providers\AuthServiceProvider::class);
        $this->app->register(\Sample\Users\Providers\EventServiceProvider::class);
        $this->app->register(\Sample\Users\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['users'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/users.php')], 'config');

        // Publish view files
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/users')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/users')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public folder.
        $this->publishes([__DIR__ . '/../../../../public' => public_path('/')], 'public');
    }
}
